<p align="center">
  <img src="https://raw.githubusercontent.com/rk4bir/USCodeKit/refs/heads/main/docs/logo.png" alt="USCodeKit_logo" width="200"/>
</p>

<h1 align="center">USCodeKit</h1>

<p align="center">
<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="187.5" height="20"><linearGradient id="smooth" x2="0" y2="100%"><stop offset="0" stop-color="#bbb" stop-opacity=".1"/><stop offset="1" stop-opacity=".1"/></linearGradient><clipPath id="round"><rect width="187.5" height="20" rx="3" fill="#fff"/></clipPath><g clip-path="url(#round)"><rect width="65.5" height="20" fill="#555"/><rect x="65.5" width="122.0" height="20" fill="#007ec6"/><rect width="187.5" height="20" fill="url(#smooth)"/></g><g fill="#fff" text-anchor="middle" font-family="DejaVu Sans,Verdana,Geneva,sans-serif" font-size="110"><image x="5" y="3" width="14" height="14" xlink:href="https://dev.w3.org/SVG/tools/svgweb/samples/svg-files/python.svg"/><text x="422.5" y="150" fill="#010101" fill-opacity=".3" transform="scale(0.1)" textLength="385.0" lengthAdjust="spacing">python</text><text x="422.5" y="140" transform="scale(0.1)" textLength="385.0" lengthAdjust="spacing">python</text><text x="1255.0" y="150" fill="#010101" fill-opacity=".3" transform="scale(0.1)" textLength="1120.0" lengthAdjust="spacing">3.9, 3.10, 3.11, 3.12</text><text x="1255.0" y="140" transform="scale(0.1)" textLength="1120.0" lengthAdjust="spacing">3.9, 3.10, 3.11, 3.12</text><a xlink:href="https://www.python.org/"><rect width="65.5" height="20" fill="rgba(0,0,0,0)"/></a><a xlink:href="https://www.python.org/"><rect x="65.5" width="122.0" height="20" fill="rgba(0,0,0,0)"/></a></g></svg>
<a href="https://pypi.org/project/uscodekit/"><img src="https://badge.fury.io/py/uscodekit.svg?icon=si%3Apython" /></a>
</p>

<p align="center">
<img src="https://github.com/rk4bir/USCodeKit/actions/workflows/tests.yaml/badge.svg" alt="unittests" />
<img src="https://raw.githubusercontent.com/rk4bir/USCodeKit/refs/heads/main/docs/coverage.svg" alt="Coverage"/>
<img src="https://github.com/rk4bir/USCodeKit/actions/workflows/publish.yaml/badge.svg" />
</p>

---

> A comprehensive package that includes all the essential tools commonly used for US phone, zip code info, NAICS (2022), (upcoming more...)

## Docs

> [Hosted Docs](https://rk4bir.github.io/USCodeKit/)

- [Installation](https://rk4bir.github.io/USCodeKit/#installation)
- [Getting Started](https://rk4bir.github.io/USCodeKit/)
- **Modules**
  - [phone](https://rk4bir.github.io/USCodeKit/phone/)
  - [zip_code](https://rk4bir.github.io/USCodeKit/zip_code/)
  - [NAICS (2022)](https://rk4bir.github.io/USCodeKit/naics/)

## Installation

Using `pip`

```bash
pip install -U uscodekit
```

Using `poetry`

```bash
poetry add uscodekit
```
